DataChannelReadRequest

Struct DataChannelReadRequest 

pub struct DataChannelReadRequest {
    pub blocking: Option<bool>,
    /* private fields */
}

Fields

blocking: Option<bool>

If specified and set to false, then the call will return immediately if there is no data to read with ZX_ERR_SHOULD_WAIT. Otherwise the call has hanging get semantics and will return once data is available.